@@ -1,8 +1,7 @@
-import itertools
 import json
 import warnings
-from datetime import datetime
 
+from datetime import datetime
 from urllib.parse import urljoin
 
 from django import template
@@ -10,10 +9,12 @@ from django.conf import settings
 from django.contrib.admin.utils import quote
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.contrib.messages.constants import DEFAULT_TAGS as MESSAGE_TAGS
+from django.db.models import Min, QuerySet
 from django.template.defaultfilters import stringfilter
 from django.template.loader import render_to_string
 from django.templatetags.static import static
 from django.utils import timezone
+from django.utils.encoding import force_str
 from django.utils.html import avoid_wrapping, format_html, format_html_join
 from django.utils.safestring import mark_safe
 from django.utils.timesince import timesince
@@ -27,12 +28,15 @@ from wagtail.admin.search import admin_search_areas
 from wagtail.admin.staticfiles import versioned_static as versioned_static_func
 from wagtail.core import hooks
 from wagtail.core.models import (
-    CollectionViewRestriction, Page, PageLogEntry, PageViewRestriction, UserPagePermissionsProxy)
+    Collection, CollectionViewRestriction, Locale, Page, PageLogEntry, PageViewRestriction,
+    UserPagePermissionsProxy)
+from wagtail.core.utils import accepts_kwarg, camelcase_to_underscore
 from wagtail.core.utils import cautious_slugify as _cautious_slugify
-from wagtail.core.utils import accepts_kwarg, camelcase_to_underscore, escape_script
+from wagtail.core.utils import escape_script
 from wagtail.users.utils import get_gravatar_url
 from wagtail.utils.deprecation import RemovedInWagtail212Warning
 
+
 register = template.Library()
 
 register.filter('intcomma', intcomma)
@@ -547,20 +551,6 @@ def icon(name=None, class_name='icon', title=None, wrapped=False):
     }
 
 
-_icons_html = None
-
-
-@register.simple_tag
-def icons():
-    global _icons_html
-    if _icons_html is None:
-        icon_hooks = hooks.get_hooks('register_icons')
-        icons = sorted(itertools.chain.from_iterable(hook([]) for hook in icon_hooks))
-        _icons_html = render_to_string("wagtailadmin/shared/icons.html", {'icons': icons})
-
-    return _icons_html
-
-
 @register.filter()
 def timesince_simple(d):
     """
@@ -603,3 +593,64 @@ def format_action_log_message(log_entry):
     if not isinstance(log_entry, PageLogEntry):
         return ''
     return log_action_registry.format_message(log_entry)
+
+
+@register.simple_tag
+def format_collection(coll: Collection, min_depth: int = 2) -> str:
+    """
+    Renders a given Collection's name as a formatted string that displays its
+    hierarchical depth via indentation. If min_depth is supplied, the
+    Collection's depth is rendered relative to that depth. min_depth defaults
+    to 2, the depth of the first non-Root Collection.
+
+    Example usage: {% format_collection collection min_depth %}
+    Example output: "&nbsp;&nbsp;&nbsp;&nbsp;&#x21b3 Child Collection"
+    """
+    return coll.get_indented_name(min_depth, html=True)
+
+
+@register.simple_tag
+def minimum_collection_depth(collections: QuerySet) -> int:
+    """
+    Returns the minimum depth of the Collections in the given queryset.
+    Call this before beginning a loop through Collections that will
+    use {% format_collection collection min_depth %}.
+    """
+    return collections.aggregate(Min('depth'))['depth__min'] or 2
+
+
+@register.filter
+def user_display_name(user):
+    """
+    Returns the preferred display name for the given user object: the result of
+    user.get_full_name() if implemented and non-empty, or user.get_username() otherwise.
+    """
+    try:
+        full_name = user.get_full_name().strip()
+        if full_name:
+            return full_name
+    except AttributeError:
+        pass
+
+    try:
+        return user.get_username()
+    except AttributeError:
+        # we were passed None or something else that isn't a valid user object; return
+        # empty string to replicate the behaviour of {{ user.get_full_name|default:user.get_username }}
+        return ''
+
+
+@register.simple_tag
+def i18n_enabled():
+    return getattr(settings, 'WAGTAIL_I18N_ENABLED', False)
+
+
+@register.simple_tag
+def locales():
+    return json.dumps([
+        {
+            'code': locale.language_code,
+            'display_name': force_str(locale.get_display_name()),
+        }
+        for locale in Locale.objects.all()
+    ])
