@@ -1,10 +1,10 @@
 import datetime
 import os
+
 from unittest import mock
 
 from django.conf import settings
-from django.contrib.auth import get_user_model
-from django.contrib.auth.models import Permission
+from django.contrib.auth.models import Group, Permission
 from django.core.files.base import ContentFile
 from django.http import HttpRequest, HttpResponse
 from django.test import TestCase, modify_settings, override_settings
@@ -14,11 +14,12 @@ from django.utils.translation import gettext_lazy as _
 
 from wagtail.admin.tests.pages.timestamps import submittable_timestamp
 from wagtail.core.exceptions import PageClassNotFoundError
-from wagtail.core.models import Page, PageRevision, Site
+from wagtail.core.models import GroupPagePermission, Locale, Page, PageRevision, Site
 from wagtail.core.signals import page_published
 from wagtail.tests.testapp.models import (
-    EVENT_AUDIENCE_CHOICES, Advert, AdvertPlacement, EventCategory,
-    EventPage, EventPageCarouselItem, FilePage, ManyToManyBlogPage, SimplePage, SingleEventPage, StandardIndex, TaggedPage)
+    EVENT_AUDIENCE_CHOICES, Advert, AdvertPlacement, EventCategory, EventPage,
+    EventPageCarouselItem, FilePage, ManyToManyBlogPage, SimplePage, SingleEventPage, StandardIndex,
+    TaggedPage)
 from wagtail.tests.utils import WagtailTestUtils
 from wagtail.tests.utils.form_data import inline_formset, nested_form_data
 
@@ -82,6 +83,7 @@ class TestPageEdit(TestCase, WagtailTestUtils):
         # Tests that the edit page loads
         response = self.client.get(reverse('wagtailadmin_pages:edit', args=(self.event_page.id, )))
         self.assertEqual(response.status_code, 200)
+        self.assertEqual(response['Content-Type'], "text/html; charset=utf-8")
         self.assertContains(response, '<li class="header-meta--status">Published</li>', html=True)
 
         # Test InlinePanel labels/headings
@@ -187,8 +189,8 @@ class TestPageEdit(TestCase, WagtailTestUtils):
         # Get edit page
         response = self.client.get(reverse('wagtailadmin_pages:edit', args=(self.child_page.id, )))
 
-        # Check that the user received a 403 response
-        self.assertEqual(response.status_code, 403)
+        # Check that the user received a 302 redirected response
+        self.assertEqual(response.status_code, 302)
 
     def test_page_edit_post(self):
         # Tests simple editing
@@ -610,7 +612,7 @@ class TestPageEdit(TestCase, WagtailTestUtils):
 
     def test_page_edit_post_submit(self):
         # Create a moderator user for testing email
-        get_user_model().objects.create_superuser('moderator', 'moderator@email.com', 'password')
+        self.create_superuser('moderator', 'moderator@email.com', 'password')
 
         # Tests submitting from edit page
         post_data = {
@@ -631,7 +633,6 @@ class TestPageEdit(TestCase, WagtailTestUtils):
         # The latest revision for the page should now be in moderation
         self.assertEqual(child_page_new.current_workflow_state.status, child_page_new.current_workflow_state.STATUS_IN_PROGRESS)
 
-
     def test_page_edit_post_existing_slug(self):
         # This tests the existing slug checking on page edit
 
@@ -971,6 +972,34 @@ class TestPageEdit(TestCase, WagtailTestUtils):
         self.assertContains(response, publish_button, html=True)
         self.assertNotContains(response, "<li>%s</li>" % publish_button, html=True)
 
+    def test_edit_alias_page(self):
+        alias_page = self.event_page.create_alias(update_slug='new-event-page')
+        response = self.client.get(reverse('wagtailadmin_pages:edit', args=[alias_page.id]))
+
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response['Content-Type'], "text/html; charset=utf-8")
+
+        # Should still have status in the header
+        self.assertContains(response, '<li class="header-meta--status">Published</li>', html=True)
+
+        # Check the edit_alias.html template was used instead
+        self.assertTemplateUsed(response, 'wagtailadmin/pages/edit_alias.html')
+        original_page_edit_url = reverse('wagtailadmin_pages:edit', args=[self.event_page.id])
+        self.assertContains(response, f'<a class="button button-secondary" href="{original_page_edit_url}">Edit original page</a>', html=True)
+
+    def test_post_edit_alias_page(self):
+        alias_page = self.child_page.create_alias(update_slug='new-child-page')
+
+        # Tests simple editing
+        post_data = {
+            'title': "I've been edited!",
+            'content': "Some content",
+            'slug': 'hello-world',
+        }
+        response = self.client.post(reverse('wagtailadmin_pages:edit', args=[alias_page.id]), post_data)
+
+        self.assertEqual(response.status_code, 405)
+
 
 class TestPageEditReordering(TestCase, WagtailTestUtils):
     def setUp(self):
@@ -1809,3 +1838,61 @@ class TestNestedInlinePanel(TestCase, WagtailTestUtils):
         self.assertEqual(len(awards), 2)
         self.assertEqual(awards[0].name, "Beard Of The Century")
         self.assertEqual(awards[1].name, "Bobsleigh Olympic gold medallist")
+
+
+@override_settings(WAGTAIL_I18N_ENABLED=True)
+class TestLocaleSelector(TestCase, WagtailTestUtils):
+    fixtures = ['test.json']
+
+    def setUp(self):
+        self.christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
+        self.fr_locale = Locale.objects.create(language_code='fr')
+        self.translated_christmas_page = self.christmas_page.copy_for_translation(self.fr_locale, copy_parents=True)
+        self.user = self.login()
+
+    def test_locale_selector(self):
+        response = self.client.get(
+            reverse('wagtailadmin_pages:edit', args=[self.christmas_page.id])
+        )
+
+        self.assertContains(response, '<li class="header-meta--locale">')
+
+        edit_translation_url = reverse('wagtailadmin_pages:edit', args=[self.translated_christmas_page.id])
+        self.assertContains(response, f'<a href="{edit_translation_url}" aria-label="French" class="u-link is-live">')
+
+    @override_settings(WAGTAIL_I18N_ENABLED=False)
+    def test_locale_selector_not_present_when_i18n_disabled(self):
+        response = self.client.get(
+            reverse('wagtailadmin_pages:edit', args=[self.christmas_page.id])
+        )
+
+        self.assertNotContains(response, '<li class="header-meta--locale">')
+
+        edit_translation_url = reverse('wagtailadmin_pages:edit', args=[self.translated_christmas_page.id])
+        self.assertNotContains(response, f'<a href="{edit_translation_url}" aria-label="French" class="u-link is-live">')
+
+    def test_locale_dropdown_not_present_without_permission_to_edit(self):
+        # Remove user's permissions to edit French tree
+        en_events_index = Page.objects.get(url_path='/home/events/')
+        group = Group.objects.get(name='Moderators')
+        GroupPagePermission.objects.create(
+            group=group,
+            page=en_events_index,
+            permission_type='edit',
+        )
+        self.user.is_superuser = False
+        self.user.user_permissions.add(
+            Permission.objects.get(content_type__app_label='wagtailadmin', codename='access_admin')
+        )
+        self.user.groups.add(group)
+        self.user.save()
+
+        # Locale indicator should exist, but the "French" option should be hidden
+        response = self.client.get(
+            reverse('wagtailadmin_pages:edit', args=[self.christmas_page.id])
+        )
+
+        self.assertContains(response, '<li class="header-meta--locale">')
+
+        edit_translation_url = reverse('wagtailadmin_pages:edit', args=[self.translated_christmas_page.id])
+        self.assertNotContains(response, f'<a href="{edit_translation_url}" aria-label="French" class="u-link is-live">')
