@@ -28,7 +28,7 @@ class TestDraftAccess(TestCase, WagtailTestUtils):
         self.root_page.add_child(instance=self.stream_page)
 
         # create user with admin access (but not draft_view access)
-        user = get_user_model().objects.create_user(username='bob', email='bob@email.com', password='password')
+        user = self.create_user(username='bob', password='password')
         user.user_permissions.add(
             Permission.objects.get(content_type__app_label='wagtailadmin', codename='access_admin')
         )
@@ -52,26 +52,26 @@ class TestDraftAccess(TestCase, WagtailTestUtils):
         response = self.client.get(reverse('wagtailadmin_pages:view_draft', args=(self.stream_page.id, )))
 
         # Unauthorized response (because this page type has previewing disabled)
-        self.assertEqual(response.status_code, 403)
+        self.assertRedirects(response, '/admin/')
 
     def test_draft_access_unauthorized(self):
         """Test that user without edit/publish permission can't view draft."""
-        self.assertTrue(self.client.login(username='bob', password='password'))
+        self.login(username='bob', password='password')
 
         # Try getting page draft
         response = self.client.get(reverse('wagtailadmin_pages:view_draft', args=(self.child_page.id, )))
 
-        # User gets Unauthorized response
-        self.assertEqual(response.status_code, 403)
+        # User gets redirected to the home page
+        self.assertEqual(response.status_code, 302)
 
     def test_draft_access_authorized(self):
         """Test that user with edit permission can view draft."""
         # give user the permission to edit page
-        user = get_user_model().objects.get(username='bob')
+        user = get_user_model().objects.get(email='bob@example.com')
         user.groups.add(Group.objects.get(name='Moderators'))
         user.save()
 
-        self.assertTrue(self.client.login(username='bob', password='password'))
+        self.login(username='bob', password='password')
 
         # Get add subpage page
         response = self.client.get(reverse('wagtailadmin_pages:view_draft', args=(self.child_page.id, )))
