@@ -9,9 +9,8 @@ from django.core.exceptions import FieldDoesNotExist, ImproperlyConfigured
 from django.test import RequestFactory, TestCase, override_settings
 
 from wagtail.admin.edit_handlers import (
-    FieldPanel, FieldRowPanel, InlinePanel, ObjectList, PageChooserPanel,
-    RichTextFieldPanel, TabbedInterface, extract_panel_definitions_from_model_class,
-    get_form_for_model)
+    FieldPanel, FieldRowPanel, InlinePanel, ObjectList, PageChooserPanel, RichTextFieldPanel,
+    TabbedInterface, extract_panel_definitions_from_model_class, get_form_for_model)
 from wagtail.admin.forms import WagtailAdminModelForm, WagtailAdminPageForm
 from wagtail.admin.rich_text import DraftailRichTextArea
 from wagtail.admin.widgets import AdminAutoHeightTextInput, AdminDateInput, AdminPageChooser
@@ -19,8 +18,8 @@ from wagtail.core.models import Page, Site
 from wagtail.images.edit_handlers import ImageChooserPanel
 from wagtail.tests.testapp.forms import ValidatedPageForm
 from wagtail.tests.testapp.models import (
-    EventPage, EventPageChooserModel, EventPageSpeaker, PageChooserModel,
-    SimplePage, ValidatedPage)
+    EventPage, EventPageChooserModel, EventPageSpeaker, PageChooserModel, RestaurantPage,
+    RestaurantTag, SimplePage, ValidatedPage)
 from wagtail.tests.utils import WagtailTestUtils
 
 
@@ -119,6 +118,29 @@ class TestGetFormForModel(TestCase):
         self.assertEqual(type(form.fields['date_from']), forms.DateField)
         self.assertEqual(type(form.fields['date_from'].widget), forms.PasswordInput)
 
+    def test_tag_widget_is_passed_tag_model(self):
+        RestaurantPageForm = get_form_for_model(
+            RestaurantPage, form_class=WagtailAdminPageForm
+        )
+        form_html = RestaurantPageForm().as_p()
+        self.assertIn('/admin/tag\\u002Dautocomplete/tests/restauranttag/', form_html)
+
+        # widget should pick up the free_tagging=False attribute on the tag model
+        # and set itself to autocomplete only
+        self.assertIn('"autocompleteOnly": true', form_html)
+
+        # Free tagging should also be disabled at the form field validation level
+        RestaurantTag.objects.create(name='Italian', slug='italian')
+        RestaurantTag.objects.create(name='Indian', slug='indian')
+
+        form = RestaurantPageForm({
+            'title': 'Buonasera',
+            'slug': 'buonasera',
+            'tags': "Italian, delicious",
+        })
+        self.assertTrue(form.is_valid())
+        self.assertEqual(form.cleaned_data['tags'], ["Italian"])
+
 
 def clear_edit_handler(page_cls):
     def decorator(fn):
@@ -365,7 +387,7 @@ class TestObjectList(TestCase):
         self.assertInHTML('<label for="id_date_from">Start date</label>', result)
 
         # result should include help text for children
-        self.assertIn('<div class="object-help help"><span class="icon-help-inverse" aria-hidden="true"></span>Not required if event is on a single day</div>', result)
+        self.assertInHTML('<div class="object-help help"> <svg class="icon icon-help default" aria-hidden="true" focusable="false"><use href="#icon-help"></use></svg> Not required if event is on a single day</div>', result)
 
         # result should contain rendered content from descendants
         self.assertIn('Abergavenny sheepdog trials</textarea>', result)
@@ -397,6 +419,18 @@ class TestFieldPanel(TestCase):
         with self.assertRaises(FieldDoesNotExist):
             field_panel.db_field
 
+    def test_override_heading(self):
+        # unless heading is specified in keyword arguments, an edit handler with bound form should take its
+        # heading from the bound field label
+        bound_panel = self.end_date_panel.bind_to(form=self.EventPageForm())
+        self.assertEqual(bound_panel.heading, bound_panel.bound_field.label)
+
+        # if heading is explicitly provided to constructor, that heading should be taken in
+        # preference to the field's label
+        end_date_panel_with_overridden_heading = (FieldPanel('date_to', classname='full-width', heading="New heading")
+                                                  .bind_to(model=EventPage, request=self.request, form=self.EventPageForm()))
+        self.assertEqual(end_date_panel_with_overridden_heading.heading, "New heading")
+
     def test_render_as_object(self):
         form = self.EventPageForm(
             {'title': 'Pontypridd sheepdog trials', 'date_from': '2014-07-20', 'date_to': '2014-07-22'},
@@ -917,7 +951,6 @@ class TestInlinePanel(TestCase, WagtailTestUtils):
 
         self.assertIn('maxForms: 1000', panel.render_js_init())
 
-
     def test_invalid_inlinepanel_declaration(self):
         with self.ignore_deprecation_warnings():
             self.assertRaises(TypeError, lambda: InlinePanel(label="Speakers"))
