@@ -50,6 +50,8 @@ class TestAdminPageChooserWidget(TestCase):
 
         html = widget.render_html('test', self.child_page, {})
         self.assertInHTML("""<input name="test" type="hidden" value="%d" />""" % self.child_page.id, html)
+        # SimplePage has a custom get_admin_display_title method which should be reflected here
+        self.assertInHTML("foobarbaz (simple page)", html)
 
     def test_render_js_init_with_value(self):
         widget = widgets.AdminPageChooser()
@@ -198,7 +200,6 @@ class TestAdminTagWidget(TestCase):
                 return json.loads('[%s]' % params_raw)
         return []
 
-
     def test_render_js_init_basic(self):
         """Checks that the 'initTagField' is correctly added to the inline script for tag widgets"""
         widget = widgets.AdminTagWidget()
@@ -211,7 +212,6 @@ class TestAdminTagWidget(TestCase):
             ['alpha', '/admin/tag-autocomplete/', {'allowSpaces': True, 'tagLimit': None, 'autocompleteOnly': False}]
         )
 
-
     @override_settings(TAG_SPACES_ALLOWED=False)
     def test_render_js_init_no_spaces_allowed(self):
         """Checks that the 'initTagField' includes the correct value based on TAG_SPACES_ALLOWED in settings"""
@@ -225,7 +225,6 @@ class TestAdminTagWidget(TestCase):
             ['alpha', '/admin/tag-autocomplete/', {'allowSpaces': False, 'tagLimit': None, 'autocompleteOnly': False}]
         )
 
-
     @override_settings(TAG_LIMIT=5)
     def test_render_js_init_with_tag_limit(self):
         """Checks that the 'initTagField' includes the correct value based on TAG_LIMIT in settings"""
