@@ -1,16 +1,16 @@
 import json
 import logging
+
 from unittest import mock
 
 from django.conf import settings
-from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Group, Permission
 from django.core import mail
 from django.core.mail import EmailMultiAlternatives
 from django.test import TestCase, override_settings
 from django.urls import reverse
-
 from freezegun import freeze_time
+
 from wagtail.core.models import (
     GroupApprovalTask, Page, Task, TaskState, Workflow, WorkflowPage, WorkflowState, WorkflowTask)
 from wagtail.core.signals import page_published
@@ -32,7 +32,7 @@ class TestWorkflowsIndexView(TestCase, WagtailTestUtils):
         delete_existing_workflows()
         self.login()
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -40,7 +40,7 @@ class TestWorkflowsIndexView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -104,7 +104,7 @@ class TestWorkflowsCreateView(TestCase, WagtailTestUtils):
         self.task_1 = SimpleTask.objects.create(name="first_task")
         self.task_2 = SimpleTask.objects.create(name="second_task")
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -112,7 +112,7 @@ class TestWorkflowsCreateView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -160,7 +160,6 @@ class TestWorkflowsCreateView(TestCase, WagtailTestUtils):
             'pages-1-DELETE': [''],
         })
 
-
         # Should redirect back to index
         self.assertRedirects(response, reverse('wagtailadmin_workflows:index'))
 
@@ -234,7 +233,7 @@ class TestWorkflowsEditView(TestCase, WagtailTestUtils):
         self.page = Page.objects.first()
         WorkflowPage.objects.create(workflow=self.workflow, page=self.page)
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -242,7 +241,7 @@ class TestWorkflowsEditView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -291,7 +290,6 @@ class TestWorkflowsEditView(TestCase, WagtailTestUtils):
             'pages-1-DELETE': [''],
         })
 
-
         # Should redirect back to index
         self.assertRedirects(response, reverse('wagtailadmin_workflows:index'))
 
@@ -396,7 +394,7 @@ class TestRemoveWorkflow(TestCase, WagtailTestUtils):
         self.page = Page.objects.first()
         WorkflowPage.objects.create(workflow=self.workflow, page=self.page)
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -404,7 +402,7 @@ class TestRemoveWorkflow(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -424,7 +422,7 @@ class TestRemoveWorkflow(TestCase, WagtailTestUtils):
     def test_no_permissions(self):
         self.login(user=self.editor)
         response = self.post()
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(response.status_code, 302)
 
     def test_post_with_permission(self):
         self.login(user=self.moderator)
@@ -438,7 +436,7 @@ class TestTaskIndexView(TestCase, WagtailTestUtils):
         delete_existing_workflows()
         self.login()
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -446,7 +444,7 @@ class TestTaskIndexView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -509,7 +507,7 @@ class TestCreateTaskView(TestCase, WagtailTestUtils):
         delete_existing_workflows()
         self.login()
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -517,7 +515,7 @@ class TestCreateTaskView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -597,7 +595,7 @@ class TestEditTaskView(TestCase, WagtailTestUtils):
         self.login()
         self.task = GroupApprovalTask.objects.create(name="test_task")
 
-        self.editor = get_user_model().objects.create_user(
+        self.editor = self.create_user(
             username='editor',
             email='editor@email.com',
             password='password',
@@ -605,7 +603,7 @@ class TestEditTaskView(TestCase, WagtailTestUtils):
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.editor)
 
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -659,14 +657,14 @@ class TestEditTaskView(TestCase, WagtailTestUtils):
 class TestSubmitToWorkflow(TestCase, WagtailTestUtils):
     def setUp(self):
         delete_existing_workflows()
-        self.submitter = get_user_model().objects.create_user(
+        self.submitter = self.create_user(
             username='submitter',
             email='submitter@email.com',
             password='password',
         )
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.submitter)
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -674,7 +672,7 @@ class TestSubmitToWorkflow(TestCase, WagtailTestUtils):
         moderators = Group.objects.get(name='Moderators')
         moderators.user_set.add(self.moderator)
 
-        self.superuser = get_user_model().objects.create_superuser(
+        self.superuser = self.create_superuser(
             username='superuser',
             email='superuser@email.com',
             password='password',
@@ -828,7 +826,6 @@ class TestSubmitToWorkflow(TestCase, WagtailTestUtils):
         self.assertEqual(workflow_state.status, WorkflowState.STATUS_CANCELLED)
         self.assertEqual(workflow_state.current_task_state.status, TaskState.STATUS_CANCELLED)
 
-
     def test_email_headers(self):
         # Submit
         self.submit()
@@ -842,7 +839,7 @@ class TestSubmitToWorkflow(TestCase, WagtailTestUtils):
 class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
     def setUp(self):
         delete_existing_workflows()
-        self.submitter = get_user_model().objects.create_user(
+        self.submitter = self.create_user(
             username='submitter',
             first_name='Sebastian',
             last_name='Mitter',
@@ -851,7 +848,7 @@ class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
         )
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.submitter)
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -859,7 +856,7 @@ class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
         moderators = Group.objects.get(name='Moderators')
         moderators.user_set.add(self.moderator)
 
-        self.superuser = get_user_model().objects.create_superuser(
+        self.superuser = self.create_superuser(
             username='superuser',
             email='superuser@email.com',
             password='password',
@@ -981,8 +978,8 @@ class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
 
         # Post
         response = self.client.post(reverse('wagtailadmin_pages:workflow_action', args=(self.page.id, 'approve', self.page.current_workflow_task_state.id)))
-        # Check that the user received a 403 response
-        self.assertEqual(response.status_code, 403)
+        # Check that the user received a permission denied response
+        self.assertRedirects(response, '/admin/')
 
     def test_edit_view_workflow_cancellation_not_in_group(self):
         """
@@ -1035,8 +1032,8 @@ class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
         # Post
         response = self.client.post(reverse('wagtailadmin_pages:workflow_action', args=(self.page.id, 'reject', self.page.current_workflow_task_state.id)))
 
-        # Check that the user received a 403 response
-        self.assertEqual(response.status_code, 403)
+        # Check that the user received a permission denied response
+        self.assertRedirects(response, '/admin/')
 
     def test_collect_workflow_action_data_get(self):
         """
@@ -1138,19 +1135,19 @@ class TestApproveRejectWorkflow(TestCase, WagtailTestUtils):
 class TestNotificationPreferences(TestCase, WagtailTestUtils):
     def setUp(self):
         delete_existing_workflows()
-        self.submitter = get_user_model().objects.create_user(
+        self.submitter = self.create_user(
             username='submitter',
             email='submitter@email.com',
             password='password',
         )
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.submitter)
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
         )
-        self.moderator2 = get_user_model().objects.create_user(
+        self.moderator2 = self.create_user(
             username='moderator2',
             email='moderator2@email.com',
             password='password',
@@ -1159,7 +1156,7 @@ class TestNotificationPreferences(TestCase, WagtailTestUtils):
         moderators.user_set.add(self.moderator)
         moderators.user_set.add(self.moderator2)
 
-        self.superuser = get_user_model().objects.create_superuser(
+        self.superuser = self.create_superuser(
             username='superuser',
             email='superuser@email.com',
             password='password',
@@ -1345,19 +1342,19 @@ class TestNotificationPreferences(TestCase, WagtailTestUtils):
 class TestDisableViews(TestCase, WagtailTestUtils):
     def setUp(self):
         delete_existing_workflows()
-        self.submitter = get_user_model().objects.create_user(
+        self.submitter = self.create_user(
             username='submitter',
             email='submitter@email.com',
             password='password',
         )
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.submitter)
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
         )
-        self.moderator2 = get_user_model().objects.create_user(
+        self.moderator2 = self.create_user(
             username='moderator2',
             email='moderator2@email.com',
             password='password',
@@ -1366,7 +1363,7 @@ class TestDisableViews(TestCase, WagtailTestUtils):
         moderators.user_set.add(self.moderator)
         moderators.user_set.add(self.moderator2)
 
-        self.superuser = get_user_model().objects.create_superuser(
+        self.superuser = self.create_superuser(
             username='superuser',
             email='superuser@email.com',
             password='password',
@@ -1659,14 +1656,14 @@ class TestWorkflowUsageView(TestCase, WagtailTestUtils):
 class TestWorkflowStatus(TestCase, WagtailTestUtils):
     def setUp(self):
         delete_existing_workflows()
-        self.submitter = get_user_model().objects.create_user(
+        self.submitter = self.create_user(
             username='submitter',
             email='submitter@email.com',
             password='password',
         )
         editors = Group.objects.get(name='Editors')
         editors.user_set.add(self.submitter)
-        self.moderator = get_user_model().objects.create_user(
+        self.moderator = self.create_user(
             username='moderator',
             email='moderator@email.com',
             password='password',
@@ -1674,7 +1671,7 @@ class TestWorkflowStatus(TestCase, WagtailTestUtils):
         moderators = Group.objects.get(name='Moderators')
         moderators.user_set.add(self.moderator)
 
-        self.superuser = get_user_model().objects.create_superuser(
+        self.superuser = self.create_superuser(
             username='superuser',
             email='superuser@email.com',
             password='password',
@@ -1734,9 +1731,9 @@ class TestWorkflowStatus(TestCase, WagtailTestUtils):
     def test_workflow_status_modal(self):
         workflow_status_url = reverse('wagtailadmin_pages:workflow_status', args=(self.page.id, ))
 
-        # The page workflow status view should 403 when the page is but a draft
+        # The page workflow status view should return permission denied when the page is but a draft
         response = self.client.get(workflow_status_url)
-        self.assertEqual(response.status_code, 403)
+        self.assertRedirects(response, '/admin/')
 
         # Submit for moderation
         self.submit()
