@@ -1,19 +1,21 @@
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.auth import views as auth_views
 from django.contrib.auth import update_session_auth_hash
+from django.contrib.auth import views as auth_views
 from django.contrib.auth.forms import PasswordChangeForm
 from django.http import Http404
-from django.shortcuts import redirect, render
+from django.shortcuts import redirect
+from django.template.response import TemplateResponse
 from django.urls import reverse, reverse_lazy
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.utils.translation import override
 from django.views.decorators.debug import sensitive_post_parameters
 
 from wagtail.admin.forms.auth import LoginForm, PasswordResetForm
 from wagtail.core import hooks
 from wagtail.users.forms import (
-    AvatarPreferencesForm, CurrentTimeZoneForm, EmailForm, NameForm, NotificationPreferencesForm, PreferredLanguageForm)
+    AvatarPreferencesForm, CurrentTimeZoneForm, EmailForm, NameForm, NotificationPreferencesForm,
+    PreferredLanguageForm)
 from wagtail.users.models import UserProfile
 from wagtail.utils.loading import get_custom_form
 
@@ -52,7 +54,7 @@ def account(request):
         if item:
             items.append(item)
 
-    return render(request, 'wagtailadmin/account/account.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/account.html', {
         'items': items,
     })
 
@@ -79,7 +81,7 @@ def change_password(request):
     else:
         form = None
 
-    return render(request, 'wagtailadmin/account/change_password.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/change_password.html', {
         'form': form,
         'can_change_password': can_change_password,
     })
@@ -98,7 +100,7 @@ def change_email(request):
     else:
         form = EmailForm(instance=request.user)
 
-    return render(request, 'wagtailadmin/account/change_email.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/change_email.html', {
         'form': form,
     })
 
@@ -114,7 +116,7 @@ def change_name(request):
     else:
         form = NameForm(instance=request.user)
 
-    return render(request, 'wagtailadmin/account/change_name.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/change_name.html', {
         'form': form,
     })
 
@@ -169,7 +171,7 @@ def notification_preferences(request):
     if not form.fields:
         return redirect('wagtailadmin_account')
 
-    return render(request, 'wagtailadmin/account/notification_preferences.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/notification_preferences.html', {
         'form': form,
     })
 
@@ -188,7 +190,7 @@ def language_preferences(request):
     else:
         form = PreferredLanguageForm(instance=UserProfile.get_for_user(request.user))
 
-    return render(request, 'wagtailadmin/account/language_preferences.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/language_preferences.html', {
         'form': form,
     })
 
@@ -204,7 +206,7 @@ def current_time_zone(request):
     else:
         form = CurrentTimeZoneForm(instance=UserProfile.get_for_user(request.user))
 
-    return render(request, 'wagtailadmin/account/current_time_zone.html', {
+    return TemplateResponse(request, 'wagtailadmin/account/current_time_zone.html', {
         'form': form,
     })
 
@@ -220,7 +222,7 @@ def change_avatar(request):
     else:
         form = AvatarPreferencesForm(instance=UserProfile.get_for_user(request.user))
 
-    return render(request, 'wagtailadmin/account/change_avatar.html', {'form': form})
+    return TemplateResponse(request, 'wagtailadmin/account/change_avatar.html', {'form': form})
 
 
 class LoginView(auth_views.LoginView):
