@@ -1,13 +1,14 @@
+from django.core.exceptions import PermissionDenied
 from django.shortcuts import redirect
 from django.urls import reverse
-from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import gettext as _
+from django.utils.translation import gettext_lazy
 from django.views.generic.base import TemplateResponseMixin
 from django.views.generic.edit import BaseCreateView, BaseDeleteView, BaseUpdateView
 from django.views.generic.list import BaseListView
 
 from wagtail.admin import messages
-from wagtail.admin.auth import permission_denied
+from wagtail.core import hooks
 
 
 class PermissionCheckedMixin:
@@ -33,17 +34,34 @@ class PermissionCheckedMixin:
                 if not self.permission_policy.user_has_permission(
                     request.user, self.permission_required
                 ):
-                    return permission_denied(request)
+                    raise PermissionDenied
 
             if self.any_permission_required is not None:
                 if not self.permission_policy.user_has_any_permission(
                     request.user, self.any_permission_required
                 ):
-                    return permission_denied(request)
+                    raise PermissionDenied
 
         return super().dispatch(request, *args, **kwargs)
 
 
+class HookResponseMixin:
+    """
+    A mixin for class-based views to support hooks like `before_edit_page`, which are triggered
+    during execution of some operation and can return a response to halt that operation.
+    """
+
+    def run_hook(self, hook_name, *args, **kwargs):
+        """
+        Run the named hook, passing args and kwargs to each function registered under that hook name.
+        If any return an HttpResponse, stop processing and return that response
+        """
+        for fn in hooks.get_hooks(hook_name):
+            result = fn(*args, **kwargs)
+            if hasattr(result, 'status_code'):
+                return result
+
+
 class IndexView(PermissionCheckedMixin, TemplateResponseMixin, BaseListView):
     model = None
     header_icon = ''
@@ -123,11 +141,11 @@ class EditView(PermissionCheckedMixin, TemplateResponseMixin, BaseUpdateView):
     index_url_name = None
     edit_url_name = None
     delete_url_name = None
-    page_title = ugettext_lazy("Editing")
+    page_title = gettext_lazy("Editing")
     context_object_name = None
     template_name = 'wagtailadmin/generic/edit.html'
     permission_required = 'change'
-    delete_item_label = ugettext_lazy("Delete")
+    delete_item_label = gettext_lazy("Delete")
     success_message = None
     error_message = None
 
@@ -187,7 +205,7 @@ class EditView(PermissionCheckedMixin, TemplateResponseMixin, BaseUpdateView):
         context['can_delete'] = (
             self.permission_policy is None
             or self.permission_policy.user_has_permission(self.request.user, 'delete')
-        ),
+        )
         return context
 
 
