@@ -1,16 +1,20 @@
+import itertools
+
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.auth.decorators import permission_required
 from django.db import connection
-from django.db.models import Max
-from django.http import Http404
-from django.shortcuts import render
+from django.db.models import Max, Q
+from django.http import Http404, HttpResponse
 from django.template.loader import render_to_string
+from django.template.response import TemplateResponse
 
 from wagtail.admin.navigation import get_site_for_user
 from wagtail.admin.site_summary import SiteSummaryPanel
 from wagtail.core import hooks
-from wagtail.core.models import Page, PageRevision, UserPagePermissionsProxy
+from wagtail.core.models import (
+    Page, PageRevision, TaskState, UserPagePermissionsProxy, WorkflowState)
+
 
 User = get_user_model()
 
@@ -31,6 +35,20 @@ class UpgradeNotificationPanel:
             return ""
 
 
+class IE11WarningPanel:
+    name = 'ie11_warning'
+    order = 110
+
+    def __init__(self, request):
+        self.request = request
+
+    def render(self):
+        if self.request.user.is_superuser:
+            return render_to_string('wagtailadmin/home/ie11_warning.html', {}, request=self.request)
+        else:
+            return ""
+
+
 class PagesForModerationPanel:
     name = 'pages_for_moderation'
     order = 200
@@ -47,9 +65,53 @@ class PagesForModerationPanel:
         }, request=self.request)
 
 
+class UserPagesInWorkflowModerationPanel:
+    name = 'user_pages_in_workflow_moderation'
+    order = 210
+
+    def __init__(self, request):
+        self.request = request
+        # Find in progress workflow states which are either requested by the user or on pages owned by the user
+        self.workflow_states = (
+            WorkflowState.objects.active()
+            .filter(Q(page__owner=request.user) | Q(requested_by=request.user))
+            .select_related(
+                'page', 'current_task_state', 'current_task_state__task', 'current_task_state__page_revision'
+            )
+            .order_by('-current_task_state__started_at')
+        )
+
+    def render(self):
+        return render_to_string('wagtailadmin/home/user_pages_in_workflow_moderation.html', {
+            'workflow_states': self.workflow_states
+        }, request=self.request)
+
+
+class WorkflowPagesToModeratePanel:
+    name = 'workflow_pages_to_moderate'
+    order = 220
+
+    def __init__(self, request):
+        self.request = request
+        states = (
+            TaskState.objects.reviewable_by(request.user)
+            .select_related('page_revision', 'task', 'page_revision__page')
+            .order_by('-started_at')
+        )
+        self.states = [
+            (state, state.task.specific.get_actions(page=state.page_revision.page, user=request.user), state.workflow_state.all_tasks_with_status())
+            for state in states
+        ]
+
+    def render(self):
+        return render_to_string('wagtailadmin/home/workflow_pages_to_moderate.html', {
+            'states': self.states
+        }, request=self.request)
+
+
 class LockedPagesPanel:
     name = 'locked_pages'
-    order = 250
+    order = 300
 
     def __init__(self, request):
         self.request = request
@@ -66,7 +128,7 @@ class LockedPagesPanel:
 
 class RecentEditsPanel:
     name = 'recent_edits'
-    order = 300
+    order = 250
 
     def __init__(self, request):
         self.request = request
@@ -111,9 +173,12 @@ def home(request):
     panels = [
         SiteSummaryPanel(request),
         UpgradeNotificationPanel(request),
+        IE11WarningPanel(request),
+        WorkflowPagesToModeratePanel(request),
         PagesForModerationPanel(request),
-        LockedPagesPanel(request),
+        UserPagesInWorkflowModerationPanel(request),
         RecentEditsPanel(request),
+        LockedPagesPanel(request),
     ]
 
     for fn in hooks.get_hooks('construct_homepage_panels'):
@@ -121,7 +186,7 @@ def home(request):
 
     site_details = get_site_for_user(request.user)
 
-    return render(request, "wagtailadmin/home.html", {
+    return TemplateResponse(request, "wagtailadmin/home.html", {
         'root_page': site_details['root_page'],
         'root_site': site_details['root_site'],
         'site_name': site_details['site_name'],
@@ -144,3 +209,19 @@ def default(request):
     redirected to the login page.
     """
     raise Http404
+
+
+_icons_html = None
+
+
+def icons():
+    global _icons_html
+    if _icons_html is None:
+        icon_hooks = hooks.get_hooks('register_icons')
+        all_icons = sorted(itertools.chain.from_iterable(hook([]) for hook in icon_hooks))
+        _icons_html = render_to_string("wagtailadmin/shared/icons.html", {'icons': all_icons})
+    return _icons_html
+
+
+def sprite(request):
+    return HttpResponse(icons())
