@@ -1,6 +1,5 @@
-from django.conf.urls import url
-from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.urls import path, reverse
+from django.utils.translation import gettext_lazy as _
 
 from wagtail.admin.menu import MenuItem
 from wagtail.core import hooks
@@ -11,7 +10,7 @@ from . import views
 @hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
-        url(r'^styleguide/$', views.index, name='wagtailstyleguide'),
+        path('styleguide/', views.index, name='wagtailstyleguide'),
     ]
 
 
@@ -20,6 +19,6 @@ def register_styleguide_menu_item():
     return MenuItem(
         _('Styleguide'),
         reverse('wagtailstyleguide'),
-        classnames='icon icon-image',
+        icon_name='image',
         order=1000
     )
