@@ -37,7 +37,7 @@ class TestTableBlock(TestCase):
         block = TableBlock()
         result = block.render(value)
         expected = """
-            <table role="table">
+            <table>
                 <tbody>
                     <tr><td>Test 1</td><td>Test 2</td><td>Test 3</td></tr>
                     <tr><td></td><td></td><td></td></tr>
@@ -61,9 +61,9 @@ class TestTableBlock(TestCase):
         block = TableBlock()
         result = block.render(value)
         expected = """
-            <table role="table">
+            <table>
                 <thead>
-                    <tr><th>Test 1</th><th class="htLeft">Test 2</th><th>Test 3</th></tr>
+                    <tr><th scope="col">Test 1</th><th scope="col" class="htLeft">Test 2</th><th scope="col">Test 3</th></tr>
                 </thead>
                 <tbody>
                     <tr><td></td><td class="htRight"></td><td></td></tr>
@@ -90,7 +90,7 @@ class TestTableBlock(TestCase):
             ]
         })
         expected = """
-            <table role="table">
+            <table>
                 <tbody>
                     <tr><td></td><td></td><td></td></tr>
                     <tr><td></td><td></td><td></td></tr>
@@ -110,7 +110,7 @@ class TestTableBlock(TestCase):
                           [None, None, None]]}
 
         expected = """
-            <table role="table">
+            <table>
                 <tbody>
                     <tr><td>&lt;p&gt;&lt;strong&gt;Test&lt;/strong&gt;&lt;/p&gt;</td><td></td><td></td></tr>
                     <tr><td></td><td></td><td></td></tr>
@@ -131,9 +131,9 @@ class TestTableBlock(TestCase):
                  'data': [['Foo', 'Bar', 'Baz'], [None, None, None], [None, None, None]]}
 
         expected = """
-            <table role="table">
+            <table>
                 <thead>
-                    <tr><th>Foo</th><th>Bar</th><th>Baz</th></tr>
+                    <tr><th scope="col">Foo</th><th scope="col">Bar</th><th scope="col">Baz</th></tr>
                 </thead>
                 <tbody>
                     <tr><td></td><td></td><td></td></tr>
@@ -153,11 +153,11 @@ class TestTableBlock(TestCase):
                  'data': [['Foo', 'Bar', 'Baz'], ['one', 'two', 'three'], ['four', 'five', 'six']]}
 
         expected = """
-            <table role="table">
+            <table>
                 <tbody>
-                    <tr><th>Foo</th><td>Bar</td><td>Baz</td></tr>
-                    <tr><th>one</th><td>two</td><td>three</td></tr>
-                    <tr><th>four</th><td>five</td><td>six</td></tr>
+                    <tr><th scope="row">Foo</th><td>Bar</td><td>Baz</td></tr>
+                    <tr><th scope="row">one</th><td>two</td><td>three</td></tr>
+                    <tr><th scope="row">four</th><td>five</td><td>six</td></tr>
                 </tbody>
             </table>
         """
@@ -173,13 +173,13 @@ class TestTableBlock(TestCase):
                  'data': [['Foo', 'Bar', 'Baz'], ['one', 'two', 'three'], ['four', 'five', 'six']]}
 
         expected = """
-            <table role="table">
+            <table>
                 <thead>
-                    <tr><th>Foo</th><th>Bar</th><th>Baz</th></tr>
+                    <tr><th scope="col">Foo</th><th scope="col">Bar</th><th scope="col">Baz</th></tr>
                 </thead>
                 <tbody>
-                    <tr><th>one</th><td>two</td><td>three</td></tr>
-                    <tr><th>four</th><td>five</td><td>six</td></tr>
+                    <tr><th scope="row">one</th><td>two</td><td>three</td></tr>
+                    <tr><th scope="row">four</th><td>five</td><td>six</td></tr>
                 </tbody>
             </table>
         """
@@ -246,7 +246,6 @@ class TestTableBlock(TestCase):
         self.assertIn("Test 1", result)
         self.assertIn("<div>A fascinating table.</div>", result)
 
-
     def test_table_block_caption_render(self):
         """
         Test a generic render with caption.
@@ -258,7 +257,7 @@ class TestTableBlock(TestCase):
         block = TableBlock()
         result = block.render(value)
         expected = """
-            <table role="table">
+            <table>
                 <caption>caption</caption>
                 <tbody>
                     <tr><td>Test 1</td><td>Test 2</td><td>Test 3</td></tr>
@@ -377,7 +376,6 @@ class TestTableBlockForm(WagtailTestUtils, SimpleTestCase):
         block_3_opts = TableBlock(table_options={'allowEmpty': False}).table_options
         self.assertEqual(block_3_opts['allowEmpty'], False)
 
-
     def test_tableblock_render_form(self):
         """
         Test the rendered form field generated by TableBlock.
