@@ -5,7 +5,9 @@ from django.contrib.auth.models import Group
 from django.test import Client, TestCase, override_settings
 from django.utils import timezone
 
-from wagtail.core.models import GroupPagePermission, Page, UserPagePermissionsProxy
+from wagtail.core.models import (
+    GroupApprovalTask, GroupPagePermission, Locale, Page, UserPagePermissionsProxy, Workflow,
+    WorkflowTask)
 from wagtail.tests.testapp.models import (
     BusinessSubIndex, EventIndex, EventPage, SingletonPageViaMaxCount)
 
@@ -13,8 +15,15 @@ from wagtail.tests.testapp.models import (
 class TestPagePermission(TestCase):
     fixtures = ['test.json']
 
+    def create_workflow_and_task(self):
+        workflow = Workflow.objects.create(name='test_workflow')
+        task_1 = GroupApprovalTask.objects.create(name='test_task_1')
+        task_1.groups.add(Group.objects.get(name="Event moderators"))
+        WorkflowTask.objects.create(workflow=workflow, task=task_1.task_ptr, sort_order=1)
+        return workflow, task_1
+
     def test_nonpublisher_page_permissions(self):
-        event_editor = get_user_model().objects.get(username='eventeditor')
+        event_editor = get_user_model().objects.get(email='eventeditor@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -78,7 +87,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(board_meetings_perms.can_move_to(christmas_page))
 
     def test_publisher_page_permissions(self):
-        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        event_moderator = get_user_model().objects.get(email='eventmoderator@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -134,7 +143,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(board_meetings_perms.can_move_to(christmas_page))
 
     def test_publish_page_permissions_without_edit(self):
-        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        event_moderator = get_user_model().objects.get(email='eventmoderator@example.com')
 
         # Remove 'edit' permission from the event_moderator group
         GroupPagePermission.objects.filter(group__name='Event moderators', permission_type='edit').delete()
@@ -193,14 +202,14 @@ class TestPagePermission(TestCase):
         self.assertTrue(moderator_event_perms.can_move_to(unpublished_event_page))
 
     def test_cannot_bulk_delete_without_permissions(self):
-        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        event_moderator = get_user_model().objects.get(email='eventmoderator@example.com')
         events_page = EventIndex.objects.get(url_path='/home/events/')
         events_perms = events_page.permissions_for_user(event_moderator)
 
         self.assertFalse(events_perms.can_delete())
 
     def test_can_bulk_delete_with_permissions(self):
-        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        event_moderator = get_user_model().objects.get(email='eventmoderator@example.com')
         events_page = EventIndex.objects.get(url_path='/home/events/')
 
         # Assign 'bulk_delete' permission to the event_moderator group
@@ -222,7 +231,7 @@ class TestPagePermission(TestCase):
         only other permission is 'add', they cannot delete published pages or pages owned
         by other users, and therefore the bulk deletion cannot happen.
         """
-        event_editor = get_user_model().objects.get(username='eventeditor')
+        event_editor = get_user_model().objects.get(email='eventeditor@example.com')
         events_page = EventIndex.objects.get(url_path='/home/events/')
 
         # Assign 'bulk_delete' permission to the event_editor group
@@ -236,7 +245,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(events_perms.can_delete())
 
     def test_inactive_user_has_no_permissions(self):
-        user = get_user_model().objects.get(username='inactiveuser')
+        user = get_user_model().objects.get(email='inactiveuser@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
 
@@ -254,7 +263,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(unpub_perms.can_move_to(christmas_page))
 
     def test_superuser_has_full_permissions(self):
-        user = get_user_model().objects.get(username='superuser')
+        user = get_user_model().objects.get(email='superuser@example.com')
         homepage = Page.objects.get(url_path='/home/').specific
         root = Page.objects.get(url_path='/').specific
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -299,8 +308,39 @@ class TestPagePermission(TestCase):
         # cannot move because the parent_page_types rule of BusinessSubIndex forbids EventPage as a parent
         self.assertFalse(board_meetings_perms.can_move_to(unpublished_event_page))
 
+    def test_cant_move_pages_between_locales(self):
+        user = get_user_model().objects.get(email='superuser@example.com')
+        homepage = Page.objects.get(url_path='/home/').specific
+        root = Page.objects.get(url_path='/').specific
+
+        fr_locale = Locale.objects.create(language_code="fr")
+        fr_page = root.add_child(instance=Page(
+            title="French page",
+            slug="french-page",
+            locale=fr_locale,
+        ))
+
+        fr_homepage = root.add_child(instance=Page(
+            title="French homepage",
+            slug="french-homepage",
+            locale=fr_locale,
+        ))
+
+        french_page_perms = fr_page.permissions_for_user(user)
+
+        # fr_page can be moved into fr_homepage but not homepage
+        self.assertFalse(french_page_perms.can_move_to(homepage))
+        self.assertTrue(french_page_perms.can_move_to(fr_homepage))
+
+        # All pages can be moved to the root, regardless what language they are
+        self.assertTrue(french_page_perms.can_move_to(root))
+
+        events_index = Page.objects.get(url_path='/home/events/')
+        events_index_perms = events_index.permissions_for_user(user)
+        self.assertTrue(events_index_perms.can_move_to(root))
+
     def test_editable_pages_for_user_with_add_permission(self):
-        event_editor = get_user_model().objects.get(username='eventeditor')
+        event_editor = get_user_model().objects.get(email='eventeditor@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -327,7 +367,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(can_publish_pages)
 
     def test_explorable_pages(self):
-        event_editor = get_user_model().objects.get(username='eventeditor')
+        event_editor = get_user_model().objects.get(email='eventeditor@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
         someone_elses_event_page = EventPage.objects.get(url_path='/home/events/someone-elses-event/')
@@ -345,7 +385,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(explorable_pages.filter(id=about_us_page.id).exists())
 
     def test_explorable_pages_in_explorer(self):
-        event_editor = get_user_model().objects.get(username='eventeditor')
+        event_editor = get_user_model().objects.get(email='eventeditor@example.com')
 
         client = Client()
         client.force_login(event_editor)
@@ -362,7 +402,7 @@ class TestPagePermission(TestCase):
         self.assertNotIn(about_us_page.title, explorable_titles)
 
     def test_explorable_pages_with_permission_gap_in_hierarchy(self):
-        corporate_editor = get_user_model().objects.get(username='corporateeditor')
+        corporate_editor = get_user_model().objects.get(email='corporateeditor@example.com')
         user_perms = UserPagePermissionsProxy(corporate_editor)
 
         about_us_page = Page.objects.get(url_path='/home/about-us/')
@@ -376,7 +416,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(explorable_pages.filter(id=events_page.id).exists())
 
     def test_editable_pages_for_user_with_edit_permission(self):
-        event_moderator = get_user_model().objects.get(username='eventmoderator')
+        event_moderator = get_user_model().objects.get(email='eventmoderator@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -403,7 +443,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(can_publish_pages)
 
     def test_editable_pages_for_inactive_user(self):
-        user = get_user_model().objects.get(username='inactiveuser')
+        user = get_user_model().objects.get(email='inactiveuser@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -430,7 +470,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(can_publish_pages)
 
     def test_editable_pages_for_superuser(self):
-        user = get_user_model().objects.get(username='superuser')
+        user = get_user_model().objects.get(email='superuser@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -457,7 +497,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(can_publish_pages)
 
     def test_editable_pages_for_non_editing_user(self):
-        user = get_user_model().objects.get(username='admin_only_user')
+        user = get_user_model().objects.get(email='admin_only_user@example.com')
         homepage = Page.objects.get(url_path='/home/')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         unpublished_event_page = EventPage.objects.get(url_path='/home/events/tentative-unpublished-event/')
@@ -484,7 +524,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(can_publish_pages)
 
     def test_lock_page_for_superuser(self):
-        user = get_user_model().objects.get(username='superuser')
+        user = get_user_model().objects.get(email='superuser@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
         locked_page = Page.objects.get(url_path='/home/my-locked-page/')
 
@@ -496,7 +536,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(perms.can_unlock())
 
     def test_lock_page_for_moderator(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         perms = UserPagePermissionsProxy(user).for_page(christmas_page)
@@ -505,7 +545,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(perms.can_unlock())
 
     def test_lock_page_for_moderator_without_unlock_permission(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         GroupPagePermission.objects.filter(group__name='Event moderators', permission_type='unlock').delete()
@@ -516,7 +556,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.can_unlock())
 
     def test_lock_page_for_moderator_whole_locked_page_without_unlock_permission(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         # Lock the page
@@ -534,7 +574,7 @@ class TestPagePermission(TestCase):
         self.assertTrue(perms.can_unlock())
 
     def test_lock_page_for_editor(self):
-        user = get_user_model().objects.get(username='eventeditor')
+        user = get_user_model().objects.get(email='eventeditor@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         perms = UserPagePermissionsProxy(user).for_page(christmas_page)
@@ -543,7 +583,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.can_unlock())
 
     def test_lock_page_for_non_editing_user(self):
-        user = get_user_model().objects.get(username='admin_only_user')
+        user = get_user_model().objects.get(email='admin_only_user@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         perms = UserPagePermissionsProxy(user).for_page(christmas_page)
@@ -552,7 +592,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.can_unlock())
 
     def test_lock_page_for_editor_with_lock_permission(self):
-        user = get_user_model().objects.get(username='eventeditor')
+        user = get_user_model().objects.get(email='eventeditor@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         GroupPagePermission.objects.create(
@@ -569,7 +609,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.can_unlock())
 
     def test_page_locked_for_unlocked_page(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         perms = UserPagePermissionsProxy(user).for_page(christmas_page)
@@ -577,7 +617,7 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.page_locked())
 
     def test_page_locked_for_locked_page(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         # Lock the page
@@ -592,13 +632,13 @@ class TestPagePermission(TestCase):
         self.assertFalse(perms.page_locked())
 
         # Other users should see the page as locked
-        other_user = get_user_model().objects.get(username='eventeditor')
+        other_user = get_user_model().objects.get(email='eventeditor@example.com')
         other_perms = UserPagePermissionsProxy(other_user).for_page(christmas_page)
         self.assertTrue(other_perms.page_locked())
 
     @override_settings(WAGTAILADMIN_GLOBAL_PAGE_EDIT_LOCK=True)
     def test_page_locked_for_locked_page_with_global_lock_enabled(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
         christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
 
         # Lock the page
@@ -613,10 +653,58 @@ class TestPagePermission(TestCase):
         self.assertTrue(perms.page_locked())
 
         # Other users should see the page as locked, like before
-        other_user = get_user_model().objects.get(username='eventeditor')
+        other_user = get_user_model().objects.get(email='eventeditor@example.com')
         other_perms = UserPagePermissionsProxy(other_user).for_page(christmas_page)
         self.assertTrue(other_perms.page_locked())
 
+    def test_page_locked_in_workflow(self):
+        workflow, task = self.create_workflow_and_task()
+        editor = get_user_model().objects.get(email='eventeditor@example.com')
+        moderator = get_user_model().objects.get(email='eventmoderator@example.com')
+        superuser = get_user_model().objects.get(email='superuser@example.com')
+        christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
+        christmas_page.save_revision()
+        workflow.start(christmas_page, editor)
+
+        moderator_perms = UserPagePermissionsProxy(moderator).for_page(christmas_page)
+
+        # the moderator is in the group assigned to moderate the task, so the page should
+        # not be locked for them
+        self.assertFalse(moderator_perms.page_locked())
+
+        superuser_perms = UserPagePermissionsProxy(superuser).for_page(christmas_page)
+
+        # superusers can moderate any GroupApprovalTask, so the page should not be locked
+        # for them
+        self.assertFalse(superuser_perms.page_locked())
+
+        editor_perms = UserPagePermissionsProxy(editor).for_page(christmas_page)
+
+        # the editor is not in the group assigned to moderate the task, so the page should
+        # be locked for them
+        self.assertTrue(editor_perms.page_locked())
+
+    def test_page_lock_in_workflow(self):
+        workflow, task = self.create_workflow_and_task()
+        editor = get_user_model().objects.get(email='eventeditor@example.com')
+        moderator = get_user_model().objects.get(email='eventmoderator@example.com')
+        christmas_page = EventPage.objects.get(url_path='/home/events/christmas/')
+        christmas_page.save_revision()
+        workflow.start(christmas_page, editor)
+
+        moderator_perms = UserPagePermissionsProxy(moderator).for_page(christmas_page)
+
+        # the moderator is in the group assigned to moderate the task, so they can lock the page, but can't unlock it
+        # unless they're the locker
+        self.assertTrue(moderator_perms.can_lock())
+        self.assertFalse(moderator_perms.can_unlock())
+
+        editor_perms = UserPagePermissionsProxy(editor).for_page(christmas_page)
+
+        # the editor is not in the group assigned to moderate the task, so they can't lock or unlock the page
+        self.assertFalse(editor_perms.can_lock())
+        self.assertFalse(editor_perms.can_unlock())
+
 
 class TestPagePermissionTesterCanCopyTo(TestCase):
     """Tests PagePermissionTester.can_copy_to()"""
@@ -634,7 +722,7 @@ class TestPagePermissionTesterCanCopyTo(TestCase):
         homepage.add_child(instance=self.singleton_page)
 
     def test_inactive_user_cannot_copy_any_pages(self):
-        user = get_user_model().objects.get(username='inactiveuser')
+        user = get_user_model().objects.get(email='inactiveuser@example.com')
 
         # Create PagePermissionTester objects for this user, for each page
         board_meetings_page_perms = self.board_meetings_page.permissions_for_user(user)
@@ -647,7 +735,7 @@ class TestPagePermissionTesterCanCopyTo(TestCase):
         self.assertFalse(singleton_page_perms.can_copy_to(self.singleton_page.get_parent()))
 
     def test_no_permissions_admin_cannot_copy_any_pages(self):
-        user = get_user_model().objects.get(username='admin_only_user')
+        user = get_user_model().objects.get(email='admin_only_user@example.com')
 
         # Create PagePermissionTester objects for this user, for each page
         board_meetings_page_perms = self.board_meetings_page.permissions_for_user(user)
@@ -660,7 +748,7 @@ class TestPagePermissionTesterCanCopyTo(TestCase):
         self.assertFalse(singleton_page_perms.can_copy_to(self.singleton_page.get_parent()))
 
     def test_event_moderator_cannot_copy_a_singleton_page(self):
-        user = get_user_model().objects.get(username='eventmoderator')
+        user = get_user_model().objects.get(email='eventmoderator@example.com')
 
         # Create PagePermissionTester objects for this user, for each page
         board_meetings_page_perms = self.board_meetings_page.permissions_for_user(user)
@@ -675,7 +763,7 @@ class TestPagePermissionTesterCanCopyTo(TestCase):
         self.assertFalse(singleton_page_perms.can_copy_to(self.singleton_page.get_parent()))
 
     def test_not_even_a_superuser_can_copy_a_singleton_page(self):
-        user = get_user_model().objects.get(username='superuser')
+        user = get_user_model().objects.get(email='superuser@example.com')
 
         # Create PagePermissionTester object for this user, for each page
         board_meetings_page_perms = self.board_meetings_page.permissions_for_user(user)
