@@ -1,8 +1,12 @@
 import hashlib
 import os.path
+import urllib
+
 from contextlib import contextmanager
+from mimetypes import guess_type
 
 from django.conf import settings
+from django.core.validators import FileExtensionValidator
 from django.db import models
 from django.dispatch import Signal
 from django.urls import reverse
@@ -51,6 +55,21 @@ class AbstractDocument(CollectionMember, index.Indexed, models.Model):
         index.FilterField('uploaded_by_user'),
     ]
 
+    def clean(self):
+        """
+        Checks for WAGTAILDOCS_EXTENSIONS and validates the uploaded file
+        based on allowed extensions that were specified.
+        Warning : This doesn't always ensure that the uploaded file is valid
+        as files can be renamed to have an extension no matter what
+        data they contain.
+
+        More info : https://docs.djangoproject.com/en/3.1/ref/validators/#fileextensionvalidator
+        """
+        allowed_extensions = getattr(settings, "WAGTAILDOCS_EXTENSIONS", None)
+        if allowed_extensions:
+            validate = FileExtensionValidator(allowed_extensions)
+            validate(self.file)
+
     def is_stored_locally(self):
         """
         Returns True if the image is hosted on the local filesystem
@@ -147,6 +166,27 @@ class AbstractDocument(CollectionMember, index.Indexed, models.Model):
         from wagtail.documents.permissions import permission_policy
         return permission_policy.user_has_permission_for_instance(user, 'change', self)
 
+    @property
+    def content_type(self):
+        content_types_lookup = getattr(settings, 'WAGTAILDOCS_CONTENT_TYPES', {})
+        return (
+            content_types_lookup.get(self.file_extension.lower())
+            or guess_type(self.filename)[0]
+            or 'application/octet-stream'
+        )
+
+    @property
+    def content_disposition(self):
+        inline_content_types = getattr(
+            settings, 'WAGTAILDOCS_INLINE_CONTENT_TYPES', ['application/pdf']
+        )
+        if self.content_type in inline_content_types:
+            return 'inline'
+        else:
+            return "attachment; filename={0}; filename*=UTF-8''{0}".format(
+                urllib.parse.quote(self.filename)
+            )
+
     class Meta:
         abstract = True
         verbose_name = _('document')
