@@ -13,17 +13,13 @@ from wagtail.tests.utils import WagtailTestUtils
 class TestIssue613(TestCase, WagtailTestUtils):
     def get_elasticsearch_backend(self):
         from django.conf import settings
+
         from wagtail.search.backends import get_search_backend
 
-        backend_path = 'wagtail.search.backends.elasticsearch'
+        if 'elasticsearch' not in settings.WAGTAILSEARCH_BACKENDS:
+            raise unittest.SkipTest("No elasticsearch backend active")
 
-        # Search WAGTAILSEARCH_BACKENDS for an entry that uses the given backend path
-        for backend_name, backend_conf in settings.WAGTAILSEARCH_BACKENDS.items():
-            if backend_conf['BACKEND'] == backend_path:
-                return get_search_backend(backend_name)
-        else:
-            # no conf entry found - skip tests for this backend
-            raise unittest.SkipTest("No WAGTAILSEARCH_BACKENDS entry for the backend %s" % backend_path)
+        return get_search_backend('elasticsearch')
 
     def setUp(self):
         self.search_backend = self.get_elasticsearch_backend()
