@@ -8,13 +8,13 @@ from django.views.decorators.http import require_POST
 from django.views.decorators.vary import vary_on_headers
 
 from wagtail.admin.auth import PermissionPolicyChecker
-from wagtail.core.models import Collection
 from wagtail.search.backends import get_search_backends
 
 from .. import get_document_model
 from ..forms import get_document_form, get_document_multi_form
 from ..permissions import permission_policy
 
+
 permission_checker = PermissionPolicyChecker(permission_policy)
 
 
@@ -26,11 +26,9 @@ def add(request):
     DocumentMultiForm = get_document_multi_form(Document)
 
     collections = permission_policy.collections_user_has_permission_for(request.user, 'add')
-    if len(collections) > 1:
-        collections_to_choose = Collection.order_for_display(collections)
-    else:
+    if len(collections) < 2:
         # no need to show a collections chooser
-        collections_to_choose = None
+        collections = None
 
     if request.method == 'POST':
         if not request.is_ajax():
@@ -86,7 +84,7 @@ def add(request):
 
         return TemplateResponse(request, 'wagtaildocs/multiple/add.html', {
             'help_text': form.fields['file'].help_text,
-            'collections': collections_to_choose,
+            'collections': collections,
             'form_media': form.media,
         })
 
