@@ -1,4 +1,3 @@
-import urllib
 from wsgiref.util import FileWrapper
 
 from django.conf import settings
@@ -79,17 +78,16 @@ def serve(request, document_id, document_filename):
         # Use wagtail.utils.sendfile to serve the file;
         # this provides support for mimetypes, if-modified-since and django-sendfile backends
 
-        if hasattr(settings, 'SENDFILE_BACKEND'):
-            return sendfile(request, local_path, attachment=True, attachment_filename=doc.filename)
-        else:
+        sendfile_opts = {
+            'attachment': (doc.content_disposition != 'inline'),
+            'attachment_filename': doc.filename,
+            'mimetype': doc.content_type,
+        }
+        if not hasattr(settings, 'SENDFILE_BACKEND'):
             # Fallback to streaming backend if user hasn't specified SENDFILE_BACKEND
-            return sendfile(
-                request,
-                local_path,
-                attachment=True,
-                attachment_filename=doc.filename,
-                backend=sendfile_streaming_backend.sendfile
-            )
+            sendfile_opts['backend'] = sendfile_streaming_backend.sendfile
+
+        return sendfile(request, local_path, **sendfile_opts)
 
     else:
 
@@ -100,11 +98,11 @@ def serve(request, document_id, document_filename):
         # as a StreamingHttpResponse
 
         wrapper = FileWrapper(doc.file)
-        response = StreamingHttpResponse(wrapper, content_type='application/octet-stream')
+        response = StreamingHttpResponse(wrapper, doc.content_type)
 
         # set filename and filename* to handle non-ascii characters in filename
         # see https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Disposition
-        response['Content-Disposition'] = "attachment; filename={0}; filename*=UTF-8''{0}".format(urllib.parse.quote(doc.filename))
+        response['Content-Disposition'] = doc.content_disposition
 
         # FIXME: storage backends are not guaranteed to implement 'size'
         response['Content-Length'] = doc.file.size
