@@ -1,6 +1,7 @@
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
+
 
 EMBED_TYPES = (
     ('video', 'Video'),
