@@ -10,7 +10,6 @@ from django.views.decorators.http import require_POST
 from django.views.decorators.vary import vary_on_headers
 
 from wagtail.admin.auth import PermissionPolicyChecker
-from wagtail.core.models import Collection
 from wagtail.images import get_image_model
 from wagtail.images.fields import ALLOWED_EXTENSIONS
 from wagtail.images.forms import get_image_form
@@ -18,6 +17,7 @@ from wagtail.images.models import UploadedImage
 from wagtail.images.permissions import permission_policy
 from wagtail.search.backends import get_search_backends
 
+
 permission_checker = PermissionPolicyChecker(permission_policy)
 
 
@@ -46,11 +46,9 @@ def add(request):
     ImageForm = get_image_form(Image)
 
     collections = permission_policy.collections_user_has_permission_for(request.user, 'add')
-    if len(collections) > 1:
-        collections_to_choose = Collection.order_for_display(collections)
-    else:
+    if len(collections) < 2:
         # no need to show a collections chooser
-        collections_to_choose = None
+        collections = None
 
     if request.method == 'POST':
         if not request.is_ajax():
@@ -128,7 +126,7 @@ def add(request):
             'allowed_extensions': ALLOWED_EXTENSIONS,
             'error_max_file_size': form.fields['file'].error_messages['file_too_large_unknown_size'],
             'error_accepted_file_types': form.fields['file'].error_messages['invalid_image_extension'],
-            'collections': collections_to_choose,
+            'collections': collections,
             'form_media': form.media,
         })
 
