@@ -1,11 +1,11 @@
-from django.conf.urls import include, url
 from django.http import HttpResponse
+from django.urls import include, path
 
 from wagtail.admin import urls as wagtailadmin_urls
 from wagtail.api.v2.router import WagtailAPIRouter
 from wagtail.api.v2.views import PagesAPIViewSet
-from wagtail.contrib.sitemaps import views as sitemaps_views
 from wagtail.contrib.sitemaps import Sitemap
+from wagtail.contrib.sitemaps import views as sitemaps_views
 from wagtail.core import urls as wagtail_urls
 from wagtail.documents import urls as wagtaildocs_urls
 from wagtail.documents.api.v2.views import DocumentsAPIViewSet
@@ -15,6 +15,7 @@ from wagtail.images.tests import urls as wagtailimages_test_urls
 from wagtail.tests.testapp import urls as testapp_urls
 from wagtail.tests.testapp.models import EventSitemap
 
+
 api_router = WagtailAPIRouter('wagtailapi_v2')
 api_router.register_endpoint('pages', PagesAPIViewSet)
 api_router.register_endpoint('images', ImagesAPIViewSet)
@@ -22,25 +23,25 @@ api_router.register_endpoint('documents', DocumentsAPIViewSet)
 
 
 urlpatterns = [
-    url(r'^admin/', include(wagtailadmin_urls)),
-    url(r'^documents/', include(wagtaildocs_urls)),
-    url(r'^testimages/', include(wagtailimages_test_urls)),
-    url(r'^images/', include(wagtailimages_urls)),
+    path('admin/', include(wagtailadmin_urls)),
+    path('documents/', include(wagtaildocs_urls)),
+    path('testimages/', include(wagtailimages_test_urls)),
+    path('images/', include(wagtailimages_urls)),
 
-    url(r'^api/main/', api_router.urls),
-    url(r'^sitemap\.xml$', sitemaps_views.sitemap),
+    path('api/main/', api_router.urls),
+    path('sitemap.xml', sitemaps_views.sitemap),
 
-    url(r'^sitemap-index\.xml$', sitemaps_views.index, {
+    path('sitemap-index.xml', sitemaps_views.index, {
         'sitemaps': {'pages': Sitemap, 'events': EventSitemap(request=None)},
         'sitemap_url_name': 'sitemap',
     }),
-    url(r'^sitemap-(?P<section>.+)\.xml$', sitemaps_views.sitemap, name='sitemap'),
+    path('sitemap-<str:section>.xml', sitemaps_views.sitemap, name='sitemap'),
 
-    url(r'^testapp/', include(testapp_urls)),
+    path('testapp/', include(testapp_urls)),
 
-    url(r'^fallback/', lambda: HttpResponse('ok'), name='fallback'),
+    path('fallback/', lambda: HttpResponse('ok'), name='fallback'),
 
     # For anything not caught by a more specific rule above, hand over to
     # Wagtail's serving mechanism
-    url(r'', include(wagtail_urls)),
+    path('', include(wagtail_urls)),
 ]
