@@ -3,8 +3,8 @@ import uuid
 
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import get_language
+from django.utils.translation import gettext_lazy as _
 
 
 def upload_avatar_to(instance, filename):
