@@ -1,14 +1,17 @@
 from django.conf import settings
 from django.contrib.auth import get_user_model, update_session_auth_hash
+from django.contrib.auth.models import Group
+from django.core.exceptions import PermissionDenied
 from django.core.paginator import Paginator
 from django.db.models import Q
-from django.shortcuts import get_object_or_404, redirect, render
+from django.shortcuts import get_object_or_404, redirect
+from django.template.response import TemplateResponse
 from django.urls import reverse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.vary import vary_on_headers
 
 from wagtail.admin import messages
-from wagtail.admin.auth import any_permission_required, permission_denied, permission_required
+from wagtail.admin.auth import any_permission_required, permission_required
 from wagtail.admin.forms.search import SearchForm
 from wagtail.core import hooks
 from wagtail.core.compat import AUTH_USER_APP_LABEL, AUTH_USER_MODEL_NAME
@@ -16,6 +19,7 @@ from wagtail.users.forms import UserCreationForm, UserEditForm
 from wagtail.users.utils import user_can_delete_user
 from wagtail.utils.loading import get_custom_form
 
+
 User = get_user_model()
 
 # Typically we would check the permission 'auth.change_user' (and 'auth.add_user' /
@@ -44,10 +48,16 @@ def get_user_edit_form():
 
 @any_permission_required(add_user_perm, change_user_perm, delete_user_perm)
 @vary_on_headers('X-Requested-With')
-def index(request):
+def index(request, *args):
     q = None
     is_searching = False
 
+    group = None
+    group_filter = Q()
+    if args:
+        group = get_object_or_404(Group, id=args[0])
+        group_filter = Q(groups=group) if args else Q()
+
     model_fields = [f.name for f in User._meta.get_fields()]
 
     if 'q' in request.GET:
@@ -70,12 +80,12 @@ def index(request):
                 if 'email' in model_fields:
                     conditions |= Q(email__icontains=term)
 
-            users = User.objects.filter(conditions)
+            users = User.objects.filter(group_filter & conditions)
     else:
         form = SearchForm(placeholder=_("Search users"))
 
     if not is_searching:
-        users = User.objects.all()
+        users = User.objects.filter(group_filter)
 
     if 'last_name' in model_fields and 'first_name' in model_fields:
         users = users.order_by('last_name', 'first_name')
@@ -92,14 +102,15 @@ def index(request):
     users = paginator.get_page(request.GET.get('p'))
 
     if request.is_ajax():
-        return render(request, "wagtailusers/users/results.html", {
+        return TemplateResponse(request, "wagtailusers/users/results.html", {
             'users': users,
             'is_searching': is_searching,
             'query_string': q,
             'ordering': ordering,
         })
     else:
-        return render(request, "wagtailusers/users/index.html", {
+        return TemplateResponse(request, "wagtailusers/users/index.html", {
+            'group': group,
             'search_form': form,
             'users': users,
             'is_searching': is_searching,
@@ -131,7 +142,7 @@ def create(request):
     else:
         form = get_user_creation_form()()
 
-    return render(request, 'wagtailusers/users/create.html', {
+    return TemplateResponse(request, 'wagtailusers/users/create.html', {
         'form': form,
     })
 
@@ -168,7 +179,7 @@ def edit(request, user_id):
     else:
         form = get_user_edit_form()(instance=user, editing_self=editing_self)
 
-    return render(request, 'wagtailusers/users/edit.html', {
+    return TemplateResponse(request, 'wagtailusers/users/edit.html', {
         'user': user,
         'form': form,
         'can_delete': can_delete,
@@ -180,7 +191,7 @@ def delete(request, user_id):
     user = get_object_or_404(User, pk=user_id)
 
     if not user_can_delete_user(request.user, user):
-        return permission_denied(request)
+        raise PermissionDenied
 
     for fn in hooks.get_hooks('before_delete_user'):
         result = fn(request, user)
@@ -195,6 +206,6 @@ def delete(request, user_id):
                 return result
         return redirect('wagtailusers_users:index')
 
-    return render(request, "wagtailusers/users/confirm_delete.html", {
+    return TemplateResponse(request, "wagtailusers/users/confirm_delete.html", {
         'user': user,
     })
